@@ -374,12 +374,6 @@ update.trellis <-
             stop("the at and labels components of scales may not be lists when relation = same")
     }
 
-
-
-
-
-
-
     ## difficult stuff
 
 #             aspect
@@ -388,9 +382,6 @@ update.trellis <-
 #             xlim,
 #             ylim,
 
-
-
-
     ## stuff that may need recalculation of limits and aspect ratio
 
     recalculateLimits <- have.xlim || have.ylim || relationChanged
@@ -422,14 +413,9 @@ update.trellis <-
         else warning("Invalid value of aspect")
     }
 
-
-
-
-
     if (!missing(prepanel))
     {
         recalculateLimits <- TRUE
-
         prepanel <-
             if (is.function(prepanel)) prepanel 
             else if (is.character(prepanel)) get(prepanel)
@@ -437,10 +423,9 @@ update.trellis <-
     }
     else prepanel <- object$prepanel
 
-
     if (recalculateLimits)
     {
-        prepanel.def <- get(paste("prepanel.default", object$call[[1]], sep = "."))
+        prepanel.def <- object$prepanel.default
         laa <- limits.and.aspect(prepanel.default.function = prepanel.def,
                                  prepanel = prepanel,
                                  have.xlim = have.xlim,
@@ -453,12 +438,8 @@ update.trellis <-
                                  panel.args = object$panel.args,
                                  aspect = object$aspect.ratio)
         ##...)  ## extra arguments for prepanel (for qqmathline)
-
         object[names(laa)] <- laa
-
-
     }
-    
     object
 }
 
@@ -467,13 +448,15 @@ update.trellis <-
 ## FIXME: how to do this?
 ## `subsetting': shortcut to updating index.cond
 
-## "[.trellis" <- function(x, i, j = NULL, ...)
+## "[.trellis" <- function(x, i, j, ..., drop = FALSE)
 ## {
-##     index.cond <- list(i, 
+##     ## index.cond <-
+##     tmp <- as.list(match.call())[-(1:2)]
+##     isj <- "j" %in% names(tmp)
+##     tmp
 ## }
 
 
 
 
 
-
